pub struct IndexExternal {
pub system: String,
pub id: String,
pub url: String,
}Expand description
External tracker mirror as projected into the index ({system, id, url}).
Fields
system: Stringid: Stringurl: StringTrait Implementations
Sourceimpl Clone for IndexExternal
impl Clone for IndexExternal
Sourcefn clone(&self) -> IndexExternal
fn clone(&self) -> IndexExternal
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for IndexExternal
impl Debug for IndexExternal
Sourceimpl<'de> Deserialize<'de> for IndexExternal
impl<'de> Deserialize<'de> for IndexExternal
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<&ExternalLink> for IndexExternal
impl From<&ExternalLink> for IndexExternal
Sourcefn from(e: &ExternalLink) -> Self
fn from(e: &ExternalLink) -> Self
Converts to this type from the input type.
Sourceimpl PartialEq for IndexExternal
impl PartialEq for IndexExternal
Sourcefn eq(&self, other: &IndexExternal) -> bool
fn eq(&self, other: &IndexExternal) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for IndexExternal
impl Serialize for IndexExternal
impl Eq for IndexExternal
impl StructuralPartialEq for IndexExternal