pub fn git_is_dirty(root: &Path) -> Result<bool>Expand description
True if the working tree at root has uncommitted changes to tracked
files (index vs. worktree vs. HEAD). Untracked files are not considered.
Errors only when root is not a usable git repo.